package com.ningdatech.pmapi.performance.controller;

import com.ningdatech.basic.model.PageVo;
import com.ningdatech.log.annotation.WebLog;
import com.ningdatech.pmapi.performance.manage.IndicatorConfigManage;
import com.ningdatech.pmapi.performance.model.dto.PerformanceIndicatorProjectTemplateSaveDTO;
import com.ningdatech.pmapi.performance.model.req.PerformanceAppraisalListReq;
import com.ningdatech.pmapi.performance.model.vo.ProjectIndexTemplateVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * 绩效评价-指标配置
 * @return
 * @author CMM
 * @since 2023/07/26 16:29
 */
@RestController
@RequiredArgsConstructor
@Api(tags = "绩效评价-指标配置")
@RequestMapping("/api/v1/indicator-config")
public class IndicatorConfigController {

    private final IndicatorConfigManage indicatorConfigManage;

    @GetMapping("/project/index/template/list")
    @ApiOperation("项目指标模板列表")
    public PageVo<ProjectIndexTemplateVO> projectIndexTemplateList(PerformanceAppraisalListReq req) {
        return indicatorConfigManage.projectIndexTemplateList(req);
    }

    @GetMapping("/project/index/template/detail/{id}")
    @ApiOperation("项目指标配置模板详情")
    public ProjectIndexTemplateVO projectDetail(@PathVariable Long id) {
        return indicatorConfigManage.projectDetail(id);
    }

    @ApiOperation(value = "项目指标模版启用(禁用)", notes = "项目指标模版启用(禁用)")
    @PutMapping("/project/index/{templateId}/active/{state}")
    public String enOrDisProjectIndexTemplate(@PathVariable Long templateId,
                               @PathVariable Boolean state) {
        Boolean result = indicatorConfigManage.enOrDisProjectIndexTemplate(templateId, state);
        return Boolean.TRUE.equals(result) ? "启用项目指标模版成功":"禁用项目指标模版成功";
    }

    @PostMapping("/project/index/template/save")
    @ApiOperation("项目指标配置模板保存")
    @WebLog("项目指标配置模板保存")
    public String projectTemplateSave(@Valid @RequestBody PerformanceIndicatorProjectTemplateSaveDTO dto) {
        return indicatorConfigManage.projectTemplateSave(dto);
    }

    @PostMapping("/project/index/template/copy/{id}")
    @ApiOperation("项目指标配置模板复制")
    @WebLog("项目指标配置模板复制")
    public String projectTemplateCopy(@PathVariable Long id) {
        return indicatorConfigManage.projectTemplateCopy(id);
    }

    @PostMapping("/project/index/template/delete/{id}")
    @ApiOperation("项目指标配置模板删除")
    @WebLog("项目指标配置模板删除")
    public String projectTemplateDelete(@PathVariable Long id) {
        return indicatorConfigManage.projectTemplateDelete(id);
    }

    @GetMapping("/project/index/list")
    @ApiOperation("项目指标库列表")
    public PageVo<ProjectIndexTemplateVO> projectIndexList(PerformanceAppraisalListReq req) {
        return indicatorConfigManage.projectIndexList(req);
    }
}
